@@ -12,7 +12,7 @@ from saltfactories.utils import random_string
 
 import salt.config
 import salt.utils.files
-from tests.conftest import CODE_DIR
+from tests.conftest import CODE_DIR, FIPS_TESTRUN
 from tests.support.pkg import ApiRequest, SaltMaster, SaltMasterWindows, SaltPkgInstall
 
 log = logging.getLogger(__name__)
@@ -34,6 +34,16 @@ def _system_up_to_date(
     grains,
     shell,
 ):
+    gpg_dest = "/etc/apt/keyrings/salt-archive-keyring.gpg"
+    if os.path.exists(gpg_dest):
+        with salt.utils.files.fopen(gpg_dest, "r") as fp:
+            log.error("Salt gpg key is %s", fp.read())
+    else:
+        log.error("Salt gpg not present")
+    # download_file(
+    #    "https://packages.broadcom.com/artifactory/api/security/keypair/SaltProjectKey/public",
+    #    gpg_dest,
+    # )
     if grains["os_family"] == "Debian":
         ret = shell.run("apt", "update")
         assert ret.returncode == 0
@@ -90,12 +100,6 @@ def pytest_addoption(parser):
         action="store_true",
         help="Do not uninstall salt packages after test run is complete",
     )
-    test_selection_group.addoption(
-        "--classic",
-        default=False,
-        action="store_true",
-        help="Test an upgrade from the classic packages.",
-    )
     test_selection_group.addoption(
         "--prev-version",
         action="store",
@@ -224,14 +228,17 @@ def salt_factories_config(salt_factories_root_dir):
 
 @pytest.fixture(scope="session")
 def install_salt(request, salt_factories_root_dir):
+    if platform.is_windows():
+        conf_dir = "c:/salt/etc/salt"
+    else:
+        conf_dir = salt_factories_root_dir / "etc" / "salt"
     with SaltPkgInstall(
-        conf_dir=salt_factories_root_dir / "etc" / "salt",
+        conf_dir=conf_dir,
         pkg_system_service=request.config.getoption("--pkg-system-service"),
         upgrade=request.config.getoption("--upgrade"),
         downgrade=request.config.getoption("--downgrade"),
         no_uninstall=request.config.getoption("--no-uninstall"),
         no_install=request.config.getoption("--no-install"),
-        classic=request.config.getoption("--classic"),
         prev_version=request.config.getoption("--prev-version"),
         use_prev_version=request.config.getoption("--use-prev-version"),
     ) as fixture:
@@ -250,8 +257,8 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
     Start up a master
     """
     if platform.is_windows():
-        state_tree = "C:/salt/srv/salt"
-        pillar_tree = "C:/salt/srv/pillar"
+        state_tree = r"C:\salt\srv\salt"
+        pillar_tree = r"C:\salt\srv\pillar"
     elif platform.is_darwin():
         state_tree = "/opt/srv/salt"
         pillar_tree = "/opt/srv/pillar"
@@ -298,6 +305,9 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
             },
         },
         "fips_mode": FIPS_TESTRUN,
+        "publish_signing_algorithm": (
+            "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
+        ),
         "open_mode": True,
     }
     salt_user_in_config_file = False
@@ -354,18 +364,7 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
 
     master_script = False
     if platform.is_windows():
-        if install_salt.classic:
-            master_script = True
-        if install_salt.relenv:
-            master_script = True
-        elif not install_salt.upgrade:
-            master_script = True
-        if (
-            not install_salt.relenv
-            and install_salt.use_prev_version
-            and not install_salt.classic
-        ):
-            master_script = False
+        master_script = True
 
     if master_script:
         salt_factories.system_service = False
@@ -373,14 +372,10 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
         scripts_dir = salt_factories.root_dir / "Scripts"
         scripts_dir.mkdir(exist_ok=True)
         salt_factories.scripts_dir = scripts_dir
-        python_executable = install_salt.bin_dir / "Scripts" / "python.exe"
-        if install_salt.classic:
-            python_executable = install_salt.bin_dir / "python.exe"
-        if install_salt.relenv:
-            python_executable = install_salt.install_dir / "Scripts" / "python.exe"
+        python_executable = install_salt.install_dir / "Scripts" / "python.exe"
         salt_factories.python_executable = python_executable
         factory = salt_factories.salt_master_daemon(
-            random_string("master-"),
+            "pkg-test-master",
             defaults=config_defaults,
             overrides=config_overrides,
             factory_class=SaltMasterWindows,
@@ -388,12 +383,8 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
         )
         salt_factories.system_service = True
     else:
-
-        if install_salt.classic and platform.is_darwin():
-            os.environ["PATH"] += ":/opt/salt/bin"
-
         factory = salt_factories.salt_master_daemon(
-            random_string("master-"),
+            "pkg-test-master",
             defaults=config_defaults,
             overrides=config_overrides,
             factory_class=SaltMaster,
@@ -449,7 +440,8 @@ def salt_minion(salt_factories, salt_master, install_salt):
         "file_roots": salt_master.config["file_roots"].copy(),
         "pillar_roots": salt_master.config["pillar_roots"].copy(),
         "fips_mode": FIPS_TESTRUN,
-        "open_mode": True,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
     }
     if platform.is_windows():
         config_overrides["winrepo_dir"] = (
@@ -460,12 +452,6 @@ def salt_minion(salt_factories, salt_master, install_salt):
         )
         config_overrides["winrepo_source_dir"] = r"salt://win/repo_ng"
 
-    if install_salt.classic and platform.is_windows():
-        salt_factories.python_executable = None
-
-    if install_salt.classic and platform.is_darwin():
-        os.environ["PATH"] += ":/opt/salt/bin"
-
     factory = salt_master.salt_minion_daemon(
         minion_id,
         overrides=config_overrides,
@@ -492,6 +478,16 @@ def salt_minion(salt_factories, salt_master, install_salt):
                     continue
                 subprocess.run(["chown", "-R", "salt:salt", str(path)], check=False)
 
+    if platform.is_windows():
+        minion_pki = pathlib.Path("c:/salt/etc/salt/pki")
+        if minion_pki.exists():
+            salt.utils.files.rm_rf(minion_pki)
+
+        # Work around missing WMIC until 3008.10 has been released.
+        grainsdir = pathlib.Path("c:/salt/etc/grains")
+        grainsdir.mkdir(exist_ok=True)
+        shutil.copy(r"salt\grains\disks.py", grainsdir)
+
     factory.after_terminate(
         pytest.helpers.remove_stale_minion_key, salt_master, factory.id
     )
