@@ -2,12 +2,11 @@
     :codeauthor: Rahul Handay <rahulha@saltstack.com>
 """
 
-from collections import OrderedDict
-
 import pytest
 
 import salt.states.test as test
 from salt.exceptions import SaltInvocationError
+from salt.utils.odict import OrderedDict
 from tests.support.mock import MagicMock, patch
 
 
@@ -355,7 +354,6 @@ def test_configurable_test_state_test():
         ret = test.configurable_test_state(mock_name)
         assert ret == mock_ret
 
-    with patch.dict(test.__opts__, {"test": True}):
         mock_ret = {
             "name": mock_name,
             "changes": mock_changes,
@@ -365,7 +363,6 @@ def test_configurable_test_state_test():
         ret = test.configurable_test_state(mock_name, comment=mock_comment)
         assert ret == mock_ret
 
-    with patch.dict(test.__opts__, {"test": True}):
         mock_ret = {
             "name": mock_name,
             "changes": mock_changes,
@@ -377,7 +374,6 @@ def test_configurable_test_state_test():
         )
         assert ret == mock_ret
 
-    with patch.dict(test.__opts__, {"test": True}):
         mock_ret = {
             "name": mock_name,
             "changes": {},
@@ -389,6 +385,30 @@ def test_configurable_test_state_test():
         )
         assert ret == mock_ret
 
+        # normal test mode operation doesn't allow False result
+        mock_ret = {
+            "name": mock_name,
+            "changes": {},
+            "result": True,
+            "comment": "This is a test",
+        }
+        ret = test.configurable_test_state(
+            mock_name, changes=False, result=False, allow_test_mode_failure=False
+        )
+        assert ret == mock_ret
+
+        # test allow False result in test mode
+        mock_ret = {
+            "name": mock_name,
+            "changes": {},
+            "result": False,
+            "comment": "This is a test",
+        }
+        ret = test.configurable_test_state(
+            mock_name, changes=False, result=False, allow_test_mode_failure=True
+        )
+        assert ret == mock_ret
+
 
 def test_mod_watch():
     """
