@@ -6,9 +6,10 @@ import pathlib
 import pprint
 import re
 import shutil
+import subprocess
 import textwrap
 import time
-from typing import TYPE_CHECKING, Dict, List
+from typing import TYPE_CHECKING
 
 import attr
 import distro
@@ -50,7 +51,7 @@ class SaltPkgInstall:
     ssm_bin: pathlib.Path = attr.ib(default=None)
     bin_dir: pathlib.Path = attr.ib(default=None)
     install_dir: pathlib.Path = attr.ib(init=False)
-    binary_paths: Dict[str, List[pathlib.Path]] = attr.ib(init=False)
+    binary_paths: dict[str, list[pathlib.Path]] = attr.ib(init=False)
     config_path: str = attr.ib(init=False)
     conf_dir: pathlib.Path = attr.ib()
 
@@ -79,8 +80,8 @@ class SaltPkgInstall:
     pkg_mngr: str = attr.ib(init=False)
     rm_pkg: str = attr.ib(init=False)
     dbg_pkg: str = attr.ib(init=False)
-    salt_pkgs: List[str] = attr.ib(init=False)
-    pkgs: List[str] = attr.ib(factory=list)
+    salt_pkgs: list[str] = attr.ib(init=False)
+    pkgs: list[str] = attr.ib(factory=list)
     file_ext: bool = attr.ib(default=None)
     relenv: bool = attr.ib(default=True)
 
@@ -220,6 +221,7 @@ class SaltPkgInstall:
             version = self.prev_version
             parsed = packaging.version.parse(version)
             version = f"{parsed.major}.{parsed.minor}"
+        # ensure services stopped on Debian/Ubuntu (minic install for RedHat - non-starting)
         if self.distro_id in ("ubuntu", "debian"):
             self.stop_services()
         return version
@@ -437,7 +439,7 @@ class SaltPkgInstall:
         if downgrade:
             self.install_previous(downgrade=downgrade)
             return True
-        pkg = self.pkgs[0]
+        pkg = str(pathlib.Path(self.pkgs[0]).resolve())
         if platform.is_windows():
             if upgrade:
                 self.root = self.install_dir.parent
@@ -445,28 +447,20 @@ class SaltPkgInstall:
                 self.ssm_bin = self.install_dir / "ssm.exe"
             if pkg.endswith("exe"):
                 # Install the package
-                log.debug("Installing: %s", str(pkg))
-                # ret = self.proc.run("start", "/wait", f"\"{str(pkg)} /start-minion=0 /S\"")
-                batch_file = pathlib.Path(pkg).parent / "install_nsis.cmd"
-                batch_content = f"start /wait {str(pkg)} /start-minion=0 /S"
-                with salt.utils.files.fopen(batch_file, "w") as fp:
-                    fp.write(batch_content)
-                # Now run the batch file
-                ret = self.proc.run("cmd.exe", "/c", str(batch_file))
+                log.info("Installing: %s", str(pkg))
+                ret = self.proc.run(str(pkg), "/start-minion=0", "/S")
                 self._check_retcode(ret)
             elif pkg.endswith("msi"):
                 # Install the package
-                log.debug("Installing: %s", str(pkg))
-                # Write a batch file to run the installer. It is impossible to
-                # perform escaping of the START_MINION property that the MSI
-                # expects unless we do it via a batch file
-                batch_file = pathlib.Path(pkg).parent / "install_msi.cmd"
-                batch_content = f'msiexec /qn /i "{str(pkg)}" START_MINION=""\n'
-                with salt.utils.files.fopen(batch_file, "w") as fp:
-                    fp.write(batch_content)
-                # Now run the batch file
-                ret = self.proc.run("cmd.exe", "/c", str(batch_file))
-                self._check_retcode(ret)
+                log.info("Installing: %s", str(pkg))
+                # self.proc.run always makes the command a list even when shell
+                # is true, meaning shell being true will never work correctly.
+                ret = subprocess.run(
+                    f'msiexec.exe /qn /i {pkg} /norestart START_MINION=""',
+                    shell=True,  # nosec
+                    check=False,
+                )
+                assert ret.returncode in [0, 3010]
             else:
                 log.error("Invalid package: %s", pkg)
                 return False
@@ -489,13 +483,29 @@ class SaltPkgInstall:
             log.debug("Installing: %s", str(pkg))
             ret = self.proc.run("installer", "-pkg", str(pkg), "-target", "/")
             self._check_retcode(ret)
+
             # Stop the service installed by the installer
             self.proc.run("launchctl", "disable", f"system/{service_name}")
             self.proc.run("launchctl", "bootout", "system", str(plist_file))
+
         elif upgrade:
             env = os.environ.copy()
             extra_args = []
             if self.distro_id in ("ubuntu", "debian"):
+
+                pref_file = pathlib.Path(
+                    "/etc", "apt", "preferences.d", "salt-pin-1001"
+                )
+                pref_file.parent.mkdir(exist_ok=True)
+                pin = f"{self.artifact_version.rsplit('.', 1)[0]}.*"
+                with salt.utils.files.fopen(pref_file, "w") as fp:
+                    fp.write(
+                        f"Package: salt-*\n"
+                        f"Pin: version {pin}\n"
+                        f"Pin-Priority: 1001"
+                    )
+                log.error("Pin to %s", pin)
+
                 env["DEBIAN_FRONTEND"] = "noninteractive"
                 extra_args = [
                     "-o",
@@ -520,12 +530,13 @@ class SaltPkgInstall:
         else:
             log.info("Installing packages:\n%s", pprint.pformat(self.pkgs))
             ret = self.proc.run(self.pkg_mngr, "install", "-y", *self.pkgs)
+
         if not platform.is_darwin() and not platform.is_windows():
             # Make sure we don't have any trailing references to old package file locations
             assert ret.returncode == 0
             assert "/saltstack/salt/run" not in ret.stdout
-        log.info(ret)
-        self._check_retcode(ret)
+            log.info(ret)
+            self._check_retcode(ret)
 
     def _install_ssm_service(self, service="minion"):
         """
@@ -589,17 +600,16 @@ class SaltPkgInstall:
 
     def stop_services(self):
         """
-        Debian distros automatically start the services
-        We want to ensure our tests start with the config
-        settings we have set. This will also verify the expected
-        services are up and running.
+        Debian/Ubuntu distros automatically start the services on install
+        We want to ensure our tests start with the config settings we have set.
+        This will also verify the expected services are up and running.
         """
         retval = True
         for service in ["salt-syndic", "salt-master", "salt-minion"]:
             check_run = self.proc.run("systemctl", "status", service)
             if check_run.returncode != 0:
-                # The system was not started automatically and we
-                # are expecting it to be on install
+                # The system was not started automatically and
+                # we are expecting it to be on install on Debian/Ubuntu systems
                 log.debug("The service %s was not started on install.", service)
                 retval = False
             else:
@@ -607,10 +617,26 @@ class SaltPkgInstall:
                 self._check_retcode(stop_service)
         return retval
 
+    def restart_services(self):
+        """
+        Debian/Ubuntu distros automatically start the services
+        We want to ensure our tests start with the config settings we have set,
+        for example: after install the services are stopped (similar to RedHat not starting services on install)
+        This will also verify the expected services are up and running.
+        """
+        for service in ["salt-minion", "salt-master", "salt-syndic"]:
+            check_run = self.proc.run("systemctl", "status", service)
+            log.debug(
+                "The restart_services status, before restart, for service %s is %s.",
+                service,
+                check_run,
+            )
+            restart_service = self.proc.run("systemctl", "restart", service)
+            self._check_retcode(restart_service)
+
     def install_previous(self, downgrade=False):
         """
-        Install previous version. This is used for
-        upgrade tests.
+        Install previous version. This is used for upgrade tests.
         """
         major_ver = packaging.version.parse(self.prev_version).major
         relenv = packaging.version.parse(self.prev_version) >= packaging.version.parse(
@@ -619,9 +645,7 @@ class SaltPkgInstall:
         distro_name = self.distro_name
         if distro_name in ("almalinux", "rocky", "centos", "fedora"):
             distro_name = "redhat"
-        root_url = "salt/py3/"
-        if self.classic:
-            root_url = "py3/"
+        root_url = "https://packages.broadcom.com/artifactory"
 
         if self.distro_name in [
             "almalinux",
@@ -636,11 +660,6 @@ class SaltPkgInstall:
             # Removing EPEL repo files
             for fp in pathlib.Path("/etc", "yum.repos.d").glob("epel*"):
                 fp.unlink()
-            gpg_key = "SALTSTACK-GPG-KEY.pub"
-            if self.distro_version == "9":
-                gpg_key = "SALTSTACK-GPG-KEY2.pub"
-            if relenv:
-                gpg_key = "SALT-PROJECT-GPG-PUBKEY-2023.pub"
 
             if platform.is_aarch64():
                 arch = "arm64"
@@ -654,13 +673,25 @@ class SaltPkgInstall:
             ret = self.proc.run(
                 "rpm",
                 "--import",
-                f"https://repo.saltproject.io/{root_url}{distro_name}/{self.distro_version}/{arch}/{major_ver}/{gpg_key}",
+                "https://packages.broadcom.com/artifactory/api/security/keypair/SaltProjectKey/public",
             )
             self._check_retcode(ret)
             download_file(
-                f"https://repo.saltproject.io/{root_url}{distro_name}/{self.distro_version}/{arch}/{major_ver}.repo",
+                "https://github.com/saltstack/salt-install-guide/releases/latest/download/salt.repo",
                 f"/etc/yum.repos.d/salt-{distro_name}.repo",
             )
+
+            if "3007" in self.prev_version:
+                ret = self.proc.run(
+                    self.pkg_mngr, "config-manager", "--enable", "salt-repo-3007-sts"
+                )
+                self._check_retcode(ret)
+            else:
+                ret = self.proc.run(
+                    self.pkg_mngr, "config-manager", "--disable", "salt-repo-3007-sts"
+                )
+                self._check_retcode(ret)
+
             if self.distro_name == "photon":
                 # yum version on photon doesn't support expire-cache
                 ret = self.proc.run(self.pkg_mngr, "clean", "all")
@@ -685,12 +716,14 @@ class SaltPkgInstall:
                     if dbg_exists:
                         pkgs_to_install.remove(dbg_exists[0])
                 cmd_action = "install"
+            # pkgs = [f"{_}=={self.prev_version}" for _ in pkgs_to_install]
             ret = self.proc.run(
                 self.pkg_mngr,
                 cmd_action,
                 *pkgs_to_install,
                 "-y",
             )
+            log.error("**WTF %r", ret)
             self._check_retcode(ret)
 
         elif distro_name in ["debian", "ubuntu"]:
@@ -705,46 +738,51 @@ class SaltPkgInstall:
                 arch = "arm64"
             else:
                 arch = "amd64"
-            pathlib.Path("/etc/apt/keyrings").mkdir(parents=True, exist_ok=True)
-            gpg_dest = "salt-archive-keyring.gpg"
-            gpg_key = gpg_dest
-            if relenv:
-                gpg_key = "SALT-PROJECT-GPG-PUBKEY-2023.gpg"
 
+            pathlib.Path("/etc/apt/keyrings").mkdir(parents=True, exist_ok=True)
+            gpg_full_path = "/etc/apt/keyrings/salt-archive-keyring.pgp"
+
+            # download the gpg pub key
             download_file(
-                f"https://repo.saltproject.io/{root_url}{distro_name}/{self.distro_version}/{arch}/{major_ver}/{gpg_key}",
-                f"/etc/apt/keyrings/{gpg_dest}",
+                f"{root_url}/api/security/keypair/SaltProjectKey/public",
+                f"{gpg_full_path}",
             )
             with salt.utils.files.fopen(
                 pathlib.Path("/etc", "apt", "sources.list.d", "salt.list"), "w"
             ) as fp:
                 fp.write(
-                    f"deb [signed-by=/etc/apt/keyrings/{gpg_dest} arch={arch}] "
-                    f"https://repo.saltproject.io/{root_url}{distro_name}/{self.distro_version}/{arch}/{major_ver} {self.distro_codename} main"
+                    f"deb [signed-by={gpg_full_path} arch={arch}] "
+                    f"{root_url}/saltproject-deb/ stable main"
                 )
             self._check_retcode(ret)
-
-            cmd = [
-                self.pkg_mngr,
-                "install",
-                *self.salt_pkgs,
-                "-y",
-            ]
-
+            pref_file = pathlib.Path("/etc", "apt", "preferences.d", "salt-pin-1001")
+            pref_file.parent.mkdir(exist_ok=True)
+            pin = f"{self.prev_version.rsplit('.', 1)[0]}.*"
             if downgrade:
-                pref_file = pathlib.Path("/etc", "apt", "preferences.d", "salt.pref")
-                pref_file.parent.mkdir(exist_ok=True)
-                pref_file.write_text(
-                    textwrap.dedent(
-                        """\
-                Package: salt*
-                Pin: origin "repo.saltproject.io"
-                Pin-Priority: 1001
-                """
-                    ),
-                    encoding="utf-8",
+                pin = self.prev_version
+            with salt.utils.files.fopen(pref_file, "w") as fp:
+                fp.write(
+                    f"Package: salt-*\n" f"Pin: version {pin}\n" f"Pin-Priority: 1001"
                 )
-                cmd.append("--allow-downgrades")
+
+            cmd = [self.pkg_mngr, "install", *self.salt_pkgs, "-y"]
+
+            # if downgrade:
+            #    pref_file = pathlib.Path("/etc", "apt", "preferences.d", "salt-pin-1001")
+            #    pref_file.parent.mkdir(exist_ok=True)
+            #    # TODO: There's probably something I should put in here to say what version
+            #    # TODO: But maybe that's done elsewhere, hopefully in self.salt_pkgs
+            #    pref_file.write_text(
+            #        textwrap.dedent(
+            #            f"""\
+            #    Package: salt*
+            #    Pin: origin "{root_url}/saltproject-deb"
+            #    Pin-Priority: 1001
+            #    """
+            #        ),
+            #        encoding="utf-8",
+            #    )
+            cmd.append("--allow-downgrades")
             env = os.environ.copy()
             env["DEBIAN_FRONTEND"] = "noninteractive"
             extra_args = [
@@ -753,66 +791,67 @@ class SaltPkgInstall:
                 "-o",
                 "DPkg::Options::=--force-confold",
             ]
-            ret = self.proc.run(self.pkg_mngr, "update", *extra_args, env=env)
+            self.proc.run(self.pkg_mngr, "update", *extra_args, env=env)
 
             cmd.extend(extra_args)
-
+            log.error("Run cmd %s", cmd)
             ret = self.proc.run(*cmd, env=env)
+            log.error("cmd return %r", ret)
             # Pre-relenv packages down get downgraded to cleanly programmatically
             # They work manually, and the install tests after downgrades will catch problems with the install
+            self._check_retcode(ret)
             # Let's not check the returncode if this is the case
-            if not (
-                downgrade
-                and packaging.version.parse(self.prev_version)
-                < packaging.version.parse("3006.0")
-            ):
-                self._check_retcode(ret)
-            if downgrade:
+            # if not (
+            #    downgrade
+            #    and packaging.version.parse(self.prev_version)
+            #    < packaging.version.parse("3006.0")
+            # ):
+            #    self._check_retcode(ret)
+            if downgrade and not self.no_uninstall:
                 pref_file.unlink()
             self.stop_services()
         elif platform.is_windows():
             self.bin_dir = self.install_dir / "bin"
             self.run_root = self.bin_dir / "salt.exe"
-            self.ssm_bin = self.bin_dir / "ssm.exe"
-            if self.file_ext == "msi" or relenv:
-                self.ssm_bin = self.install_dir / "ssm.exe"
+            self.ssm_bin = self.install_dir / "ssm.exe"
+            pkg = str(pathlib.Path(self.pkgs[0]).resolve())
 
-            if not self.classic:
-                if not relenv:
-                    win_pkg = (
-                        f"salt-{self.prev_version}-1-windows-amd64.{self.file_ext}"
-                    )
-                else:
-                    if self.file_ext == "msi":
-                        win_pkg = (
-                            f"Salt-Minion-{self.prev_version}-Py3-AMD64.{self.file_ext}"
-                        )
-                    elif self.file_ext == "exe":
-                        win_pkg = f"Salt-Minion-{self.prev_version}-Py3-AMD64-Setup.{self.file_ext}"
-                win_pkg_url = f"https://repo.saltproject.io/salt/py3/windows/{major_ver}/{win_pkg}"
+            if self.file_ext == "exe":
+                win_pkg = (
+                    f"Salt-Minion-{self.prev_version}-Py3-AMD64-Setup.{self.file_ext}"
+                )
+            elif self.file_ext == "msi":
+                win_pkg = f"Salt-Minion-{self.prev_version}-Py3-AMD64.{self.file_ext}"
             else:
-                if self.file_ext == "msi":
-                    win_pkg = (
-                        f"Salt-Minion-{self.prev_version}-Py3-AMD64.{self.file_ext}"
-                    )
-                elif self.file_ext == "exe":
-                    win_pkg = f"Salt-Minion-{self.prev_version}-Py3-AMD64-Setup.{self.file_ext}"
-                win_pkg_url = f"https://repo.saltproject.io/windows/{win_pkg}"
+                log.debug("Unknown windows file extension: %s", self.file_ext)
+
+            win_pkg_url = (
+                f"{root_url}/saltproject-generic/windows/{self.prev_version}/{win_pkg}"
+            )
             pkg_path = pathlib.Path(r"C:\TEMP", win_pkg)
             pkg_path.parent.mkdir(exist_ok=True)
             download_file(win_pkg_url, pkg_path)
 
             if self.file_ext == "msi":
-                # Write a batch file to run the installer. It is impossible to
-                # perform escaping of the START_MINION property that the MSI
-                # expects unless we do it via a batch file
-                batch_file = pkg_path.parent / "install_msi.cmd"
-                batch_content = f'msiexec /qn /i {str(pkg_path)} START_MINION=""'
-                with salt.utils.files.fopen(batch_file, "w") as fp:
-                    fp.write(batch_content)
-                # Now run the batch file
-                ret = self.proc.run("cmd.exe", "/c", str(batch_file))
-                self._check_retcode(ret)
+
+                if downgrade:
+                    # MSI can not be downgraded, we must remove the newer version
+                    # before installing the old one.
+                    ret = subprocess.run(
+                        f"msiexec.exe /qn /x {pkg} /norestart",
+                        shell=True,  # nosec
+                        check=False,
+                    )
+                    assert ret.returncode == 0
+
+                # self.proc.run always makes the command a list even when shell
+                # is true, meaning shell being true will never work correctly.
+                ret = subprocess.run(
+                    f'msiexec.exe /qn /i {pkg_path} /norestart START_MINION=""',
+                    shell=True,  # nosec
+                    check=False,
+                )
+                assert ret.returncode in [0, 3010]
             else:
                 # ret = self.proc.run("start", "/wait", f"\"{pkg_path} /start-minion=0 /S\"")
                 batch_file = pkg_path.parent / "install_nsis.cmd"
@@ -827,21 +866,24 @@ class SaltPkgInstall:
             ret = self.proc.run(str(self.ssm_bin), "remove", "salt-minion", "confirm")
             self._check_retcode(ret)
 
+            # Add installation to the path
+            self.update_process_path()
+
             if self.pkg_system_service:
                 self._install_ssm_service()
 
         elif platform.is_darwin():
-            if self.classic:
-                mac_pkg = f"salt-{self.prev_version}-py3-x86_64.pkg"
-                mac_pkg_url = f"https://repo.saltproject.io/osx/{mac_pkg}"
+            if relenv and platform.is_aarch64():
+                arch = "arm64"
+            elif platform.is_aarch64() and self.classic:
+                arch = "arm64"
             else:
-                if not relenv:
-                    mac_pkg = f"salt-{self.prev_version}-1-macos-x86_64.pkg"
-                else:
-                    mac_pkg = f"salt-{self.prev_version}-py3-x86_64.pkg"
-                mac_pkg_url = (
-                    f"https://repo.saltproject.io/salt/py3/macos/{major_ver}/{mac_pkg}"
-                )
+                arch = "x86_64"
+
+            mac_pkg = f"salt-{self.prev_version}-py3-{arch}.pkg"
+            mac_pkg_url = (
+                f"{root_url}/saltproject-generic/macos/{self.prev_version}/{mac_pkg}"
+            )
 
             mac_pkg_path = f"/tmp/{mac_pkg}"
             if not os.path.exists(mac_pkg_path):
@@ -1014,11 +1056,14 @@ class SaltPkgInstall:
         if platform.is_windows():
             self.update_process_path()
 
-        if not self.no_install:
-            if self.upgrade:
-                self.install_previous()
-            else:
-                self.install()
+        if self.no_install:
+            return self
+
+        if self.upgrade:
+            self.install_previous()
+        else:
+            # assume downgrade, since no_install only used in these two cases
+            self.install()
         return self
 
     def __exit__(self, *_):
@@ -1237,7 +1282,7 @@ class PkgSsmSaltDaemonImpl(PkgSystemdSaltDaemonImpl):
                     "processes",
                     self.get_service_name(),
                 )
-                log.warning(ret)
+                log.debug("process result %s", ret)
                 if not ret.stdout or (ret.stdout and not ret.stdout.strip()):
                     if n >= 120:
                         return False
@@ -1250,7 +1295,11 @@ class PkgSsmSaltDaemonImpl(PkgSystemdSaltDaemonImpl):
                     mainpid = line.strip().split()[0]
                     self._process = psutil.Process(int(mainpid))
                     break
-        return self._process.is_running()
+        ret = self._process.is_running()
+        if not hasattr(self, "logged_running"):
+            log.error("SSM processs is running %s", ret)
+            self.logged_running = True
+        return ret
 
     def _terminate(self):
         """
@@ -1570,7 +1619,7 @@ class ApiRequest:
     account: TestAccount = attr.ib(repr=False)
     session: requests.Session = attr.ib(init=False, repr=False)
     api_uri: str = attr.ib(init=False)
-    auth_data: Dict[str, str] = attr.ib(init=False)
+    auth_data: dict[str, str] = attr.ib(init=False)
 
     @session.default
     def _default_session(self):
